package com.yihu.wlyy.web.doctor.team;

import com.yihu.wlyy.entity.doctor.profile.Doctor;
import com.yihu.wlyy.entity.doctor.team.admin.AdminTeam;
import com.yihu.wlyy.entity.patient.Patient;
import com.yihu.wlyy.service.app.account.DoctorInfoService;
import com.yihu.wlyy.service.app.team.AdminTeamService;
import com.yihu.wlyy.web.BaseController;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.json.JSONArray;
import org.json.JSONObject;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.http.MediaType;
import org.springframework.web.bind.annotation.*;

import java.util.List;
import java.util.Map;

@RestController
@RequestMapping(value = "/doctor/admin-teams", produces = MediaType.APPLICATION_JSON_UTF8_VALUE)
@Api(description = "医生行政团队")
public class AdminTeamController extends BaseController {
    @Autowired
    private DoctorInfoService doctorInfoService;

    @Autowired
    private AdminTeamService teamService;

    @Autowired
    private AdminTeamService memberService;

    @RequestMapping(value = "/count", method = RequestMethod.GET)
    @ApiOperation(value = "团队数量")
    public String teamCount() {
        try {
            long count = teamService.getTeamCount();

            JSONObject json = new JSONObject();
            json.put("count", count);
            return write(200, "OK", "data", json);
        } catch (Exception e) {
            error(e);
            return error(-1, e.getMessage());
        }
    }

    @RequestMapping(method = RequestMethod.POST)
    @ApiOperation(value = "创建团队")
    public String createTeam(@RequestParam("team_name") String teamName,
                             @RequestParam("leader_id") String leaderCode,
                             @RequestParam("org_code") String orgCode) {
        try {
            AdminTeam team = teamService.createTeam(teamName, leaderCode, orgCode);

            teamService.addMember(team.getId(), leaderCode);

            return write(200, "OK", "data", team);
        } catch (Exception e) {
            error(e);
            return error(-1, e.getMessage());
        }
    }

    @RequestMapping(value = "/{team_id}/name", method = RequestMethod.POST)
    @ApiOperation(value = "更新团队名称")
    public String updateTeamName(@PathVariable("team_id") long teamId,
                                 @RequestParam("team_name") String teamName) {
        try {
            AdminTeam team = teamService.updateTeamName(teamId, teamName);

            return write(200, "OK", "data", team);
        } catch (Exception e) {
            error(e);
            return error(-1, e.getMessage());
        }
    }

    @RequestMapping(value = "/{team_id}/leader", method = RequestMethod.POST)
    @ApiOperation(value = "更新团队领导")
    public String updateTeamLeader(@PathVariable("team_id") long teamId,
                                   @RequestParam("doctor_code") String doctorCode) {
        try {
            AdminTeam team = teamService.updateTeamLeader(teamId, doctorCode);

            return write(200, "OK", "data", team);
        } catch (Exception e) {
            error(e);
            return error(-1, e.getMessage());
        }
    }

    @RequestMapping(value = "/{team_id}", method = RequestMethod.GET)
    @ApiOperation(value = "团队信息")
    public String getTeam(@PathVariable("team_id") long teamId) {
        try {
            AdminTeam team = teamService.getTeam(teamId);

            return write(200, "OK", "data", team);
        } catch (Exception e) {
            error(e);
            return error(-1, e.getMessage());
        }
    }

    @RequestMapping(value = "/{team_id}/members", method = RequestMethod.POST)
    @ApiOperation(value = "添加团队成员，批量添加使用逗号分隔列表")
    public String addMember(@PathVariable("team_id") long teamId,
                            @RequestParam("doctor_code") String doctorCodeList) {
        try {
            String doctorCodes[] = doctorCodeList.split(",");
            for (String doctorCode : doctorCodes) {
                teamService.addMember(teamId, doctorCode);
            }

            return write(200, "OK", "data", "");
        } catch (Exception e) {
            error(e);
            return error(-1, e.getMessage());
        }
    }

    @RequestMapping(value = "/{team_id}/members", method = RequestMethod.GET)
    @ApiOperation(value = "获取团队成员")
    public String getTeamMembers(@PathVariable("team_id") long teamId) {
        try {
            List<Doctor> members = memberService.getMembers(teamId);

            return write(200, "OK", "data", new JSONArray(members));
        } catch (Exception e) {
            error(e);
            return error(-1, e.getMessage());
        }
    }

    @RequestMapping(value = "/{team_id}/members/excluded", method = RequestMethod.GET)
    @ApiOperation(value = "获取机构内不在特定团队的医生")
    public String getExcludedTeamMembers(@RequestParam("org_code") String orgCode,
                                         @PathVariable("team_id") long teamId,
                                         @RequestParam(value = "page", required = false, defaultValue = "1") int page,
                                         @RequestParam(value = "size", required = false, defaultValue = "10") int size) {
        try {
            page = page <= 0 ? 0 : page - 1;
            List<Doctor> members = memberService.getExcludedMembers(orgCode, teamId, page, size);

            return write(200, "OK", "data", new JSONArray(members));
        } catch (Exception e) {
            error(e);
            return error(-1, e.getMessage());
        }
    }

    @RequestMapping(value = "/{team_id}/members/{doctor_code}/remove", method = RequestMethod.POST)
    @ApiOperation(value = "移除成员")
    public String removeMember(@PathVariable("team_id") long teamId,
                               @PathVariable("doctor_code") String doctorCode) {

        try {
            memberService.removeMember(teamId, doctorCode);

            return write(200, "OK", "data", "");
        } catch (Exception e) {
            error(e);
            return error(-1, e.getMessage());
        }
    }

    @RequestMapping(value = "/team/{doctor_code}/teams", method = RequestMethod.GET)
    @ApiOperation(value = "获取医生团队列表")
    public String getDoctorTeams(@PathVariable("doctor_code") String doctorCode) {
        try {
            List<AdminTeam> teamList = teamService.getDoctorTeams(doctorCode);

            return write(200, "OK", "data", new JSONArray(teamList));
        } catch (Exception e) {
            error(e);
            return error(-1, e.getMessage());
        }
    }

    @RequestMapping(value = "/teams/{team_id}/signing/count", method = RequestMethod.GET)
    @ApiOperation(value = "获取团队医生的队内签约数量")
    public String getDoctorSignPatientCount(@PathVariable("team_id") long teamId) {
        try {
            List<Doctor> members = memberService.getMembers(teamId);
            Map<String, Integer> counts = memberService.getMemberSigningCount(members);

            return write(200, "OK", "data", new JSONObject(counts));
        } catch (Exception e) {
            error(e);
            return error(-1, e.getMessage());
        }
    }

    @RequestMapping(value = "/teams/{team_id}/members/{doctor_code}/signing", method = RequestMethod.GET)
    @ApiOperation(value = "获取团队医生的队内签约患者列表")
    public String getDoctorSignPatients(@PathVariable("team_id") long teamId,
                                        @PathVariable("doctor_code") String doctorCode,
                                        @RequestParam(value = "page", defaultValue = "1", required = false) int page,
                                        @RequestParam(value = "size", defaultValue = "10", required = false) int size) {
        try {
            page = page <= 0 ? 0 : page - 1;
            List<Patient> patients = memberService.getMemberSigningPatients(teamId, doctorCode, page, size);

            return write(200, "OK", "data", new JSONArray(patients));
        } catch (Exception e) {
            error(e);
            return error(-1, e.getMessage());
        }
    }
}
